/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState} from 'react'
import CloudUploadIcon from '@material-ui/icons/CloudUpload';
import {DottedBox, BlueButton} from './StyledComponents.js';

export default function DragAndDrop (props) {
    const [dropDepth, setDropDepth] = useState(0)
    const [inDropZone, toggleInDropZone] = useState(false)
    const [fileList, setFileList] = useState([])

    const handleDragEnter = e => {
        e.preventDefault();
        e.stopPropagation();

        setDropDepth(dropDepth + 1)
    };

    const handleDragLeave = e => {
        e.preventDefault();
        e.stopPropagation();

        setDropDepth(dropDepth - 1)
        if (dropDepth > 0)
            toggleInDropZone(true)
    };

    const handleDragOver = e => {
        e.preventDefault();
        e.stopPropagation();
        e.dataTransfer.dropEffect = 'copy';
        toggleInDropZone(true)
    };

    const handleDrop = e => {
        e.preventDefault();
        e.stopPropagation();
        let files = [...e.dataTransfer.files]
        
        if (files && files.length > 0) {
            props.acceptFile(files[0])
        }
    };

    const handleUpload = (e, selectorFiles : FileList) => {
        e.preventDefault();
        props.acceptFile(selectorFiles[0])
    }
    return (
        <DottedBox
            onDrop={e => handleDrop(e)}
            onDragOver={e => handleDragOver(e)}
            onDragEnter={e => handleDragEnter(e)}
            onDragLeave={e => handleDragLeave(e)}
            >
            <CloudUploadIcon className="icon"/>
            <input
                type="file"
                onChange = {(e) => handleUpload(e, e.target.files)}
                id="upload-file"
                style={{display : "none"}}
                />
            <BlueButton>
                <label htmlFor="upload-file" style={{width : "inherit", cursor : "pointer"}}>
                    ESCOLHER O ARQUIVO
                </label>
            </BlueButton>
            <span style={{marginTop : "6px"}}>Ou arrastar e soltar o arquivo aqui</span>
        </DottedBox>
    )
}
